@@ -8,6 +8,7 @@ import (
 	"syscall"
 	"time"
 
+	"github.com/containers/common/libnetwork/types"
 	spec "github.com/opencontainers/runtime-spec/specs-go"
 )
 
@@ -57,6 +58,10 @@ type ContainerBasicConfig struct {
 	// container.
 	// Optional.
 	Env map[string]string `json:"env,omitempty"`
+	// Labels nested indicates whether or not the container is allowed
+	// to run fully nested containers including SELinux labelling.
+	// Optional.
+	LabelsNested bool `json:"labels_nested,omitempty"`
 	// Labels are key-value pairs that are used to add metadata to
 	// containers.
 	// Optional.
@@ -298,7 +303,15 @@ type ContainerSecurityConfig struct {
 	// privileges flag on create, which disables gaining additional
 	// privileges (e.g. via setuid) in the container.
 	NoNewPrivileges bool `json:"no_new_privileges,omitempty"`
-
+	// Mask is the path we want to mask in the container. This masks the paths
+	// given in addition to the default list.
+	// Optional
+	Mask []string `json:"mask,omitempty"`
+	// Unmask a path in the container. Some paths are masked by default,
+	// preventing them from being accessed within the container; this undoes that masking.
+	// If ALL is passed, all paths will be unmasked.
+	// Optional.
+	Unmask []string `json:"unmask,omitempty"`
 	// IDMappings are UID and GID mappings that will be used by user
 	// namespaces.
 	// Required if UserNS is private.
@@ -326,6 +339,19 @@ type ContainerCgroupConfig struct {
 	CgroupParent string `json:"cgroup_parent,omitempty"`
 }
 
+// PerNetworkOptions allows you to set options per network the container is
+// attached to.
+type PerNetworkOptions struct {
+	// Aliases contains a list of names which the dns server should resolve to this container. Should only be set when DNSEnabled is true on the Network. If aliases are set but there is no dns support for this network the network interface implementation should ignore this and NOT error. Optional.
+	Aliases []string `json:"aliases,omitempty"`
+	// InterfaceName for this container. Required in the backend. Optional in the frontend. Will be filled with ethX (where X is a integer) when empty.
+	InterfaceName string `json:"interface_name,omitempty"`
+	// StaticIPs for this container. Optional.
+	StaticIPs []*net.IP `json:"static_ips,omitempty"`
+	// StaticMac for this container. Optional.
+	StaticMac types.HardwareAddr `json:"static_mac,omitempty"`
+}
+
 // ContainerNetworkConfig contains information on a container's network
 // configuration.
 type ContainerNetworkConfig struct {
@@ -407,6 +433,13 @@ type ContainerNetworkConfig struct {
 	// Podman, and instead sourced from the image.
 	// Conflicts with HostAdd.
 	UseImageHosts bool `json:"use_image_hosts,omitempty"`
+	// Map of networks names or ids that the container should join. You can
+	// request additional settings for each network, you can set network
+	// aliases, static ips, static mac address and the network interface name
+	// for this container on the specific network. If the map is empty and the
+	// bridge network mode is set the container will be joined to the default
+	// network.
+	Networks map[string]PerNetworkOptions `json:"newNetworks,omitempty"`
 }
 
 // ContainerResourceConfig contains information on container resource limits.
@@ -581,7 +614,8 @@ type InspectContainerConfig struct {
 	// Container working directory
 	WorkingDir string `json:"WorkingDir"`
 	// Container entrypoint
-	Entrypoint string `json:"Entrypoint"`
+	// Podman 5.0 changed this to []string, ignoring.
+	// Entrypoint []string `json:"Entrypoint"`
 	// On-build arguments - presently unused. More of Buildah's domain.
 	OnBuild *string `json:"OnBuild"`
 	// Container labels
@@ -589,7 +623,8 @@ type InspectContainerConfig struct {
 	// Container annotations
 	Annotations map[string]string `json:"Annotations"`
 	// Container stop signal
-	StopSignal uint `json:"StopSignal"`
+	// Podman 5.0 changed this to string, ignoring.
+	// StopSignal string `json:"StopSignal"`
 	// Configured healthcheck for the container
 	// Healthcheck *manifest.Schema2HealthConfig `json:"Healthcheck,omitempty"`
 	// CreateCommand is the full command plus arguments of the process the
@@ -1093,7 +1128,7 @@ type InspectBasicNetworkConfig struct {
 	IPPrefixLen int `json:"IPPrefixLen"`
 	// SecondaryIPAddresses is a list of extra IP Addresses that the
 	// container has been assigned in this network.
-	SecondaryIPAddresses []string `json:"SecondaryIPAddresses,omitempty"`
+	SecondaryIPAddresses []SecondaryIPAddresses `json:"SecondaryIPAddresses,omitempty"`
 	// IPv6Gateway is the IPv6 gateway this network will use.
 	IPv6Gateway string `json:"IPv6Gateway"`
 	// GlobalIPv6Address is the global-scope IPv6 Address for this network.
@@ -1151,6 +1186,11 @@ type InspectNetworkSettings struct {
 	Networks map[string]*InspectAdditionalNetwork `json:"Networks,omitempty"`
 }
 
+type SecondaryIPAddresses struct {
+	Addr         string `json:"Addr"`
+	PrefixLength int    `json:"PrefixLength"`
+}
+
 // InspectContainerData provides a detailed record of a container's configuration
 // and state as viewed by Libpod.
 // Large portions of this structure are defined such that the output is
